package main

import (
	"go.uber.org/zap"
	"log"
	"os"
	"gitea.pena/PenaSide/verification/internal/app"
	"gitea.pena/PenaSide/verification/internal/config"
	
	_ "gitea.pena/PenaSide/linters-golang/pkg/dummy"
	"time"
)

var (
	commit    string = os.Getenv("COMMIT")
	buildTime string = os.Getenv("BUILD_TIME")
	version   string = os.Getenv("VERSION")
)

// $env:COMMIT=$(git rev-parse --short HEAD); $env:BUILD_TIME=$(Get-Date -UFormat "%Y-%m-%dT%H:%M:%SZ"); $env:VERSION=$(git describe --tags); go run cmd/verification/main.go

func main() {
	ptime, err := time.Parse(time.RFC3339, buildTime)
	if err != nil {
		log.Println("Error parsing build time:", zap.Error(err))
		ptime = time.Now()
	}

	cfg, err := config.NewConfig("staging.env")
	if err != nil {
		log.Fatal("can't load config: ", err.Error())
	}

	app.Run(cfg, app.Build{
		Commit:    commit,
		Version:   version,
		BuildTime: ptime.Unix(),
	})
}
